==> joounit-0.8.4.jar: joo/classes/flexunit/framework/TestSuite.js <==
joo.classLoader.prepare(/*
   Copyright (c) 2008. Adobe Systems Incorporated.
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
     * Neither the name of Adobe Systems Incorporated nor the names of its
       contributors may be used to endorse or promote products derived from this
       software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

"package flexunit.framework",/*
{
   
   import flash.utils.*
   import flash.utils.describeType
   
   import flexunit.utils.**/
   
   /**
    * A <code>TestSuite</code> is a collection of tests.
    * @description
    * It runs a collection of test cases. Here is an example:
    * import samples.test.com.iterationtwo.*;
    * import flexunit.framework.*;
    * import flexunit.extensions.*;
    *
    * <code>
    * import samples.test.com.iterationtwo.*;
    * import flexunit.framework.*;
    * import flexunit.extensions.*;
    *
    * class samples.test.com.iterationtwo.AllTests
    * {
    *    public static function suite() : Test
    *    {
    *       var testSuite : TestSuite = new TestSuite();
    *
    *       testSuite.addTest( new TestSuite( TestMoney ) );
    *       testSuite.addTest( new TestSuite( TestMoneyWithSetUpTearDown ) );
    *       testSuite.addTest( TestSuiteWithSetUpTearDown.suite() );
    *
    *       return testSuite;
    *    }
    * }
    * </code>
    * A <code>TestRunner</code> can be used to run the tests in a <code>TestSuite</code><br><br>
    * The <code>TestSetup</code>class lets you add <code>setUp()</code> and <code>tearDown()</code>
    * methods to initialize and clean-up your test suites, as shown in this example:
    * <code>
    * import samples.test.com.iterationtwo.*;
    * import flexunit.framework.*;
    * import flexunit.extensions.*;
    *
    * class samples.test.com.iterationtwo.TestSuiteWithSetUpTearDown
    * {
    *    public static function suite() : Test
    *    {
    *       var testSuite : TestSuite = new TestSuite();
    *
    *       testSuite.addTest( new TestSuite( TestMoneyWithFailingTests ) );
    *
    *       var testSetUp = new TestSetup( testSuite );
    *
    *       testSetUp.setUp = setUp
    *       testSetUp.tearDown = tearDown;
    *
    *       return testSetUp;
    *    }
    *
    *    public static function setUp()
    *    {
    *    }
    *
    *    public static function tearDown()
    *    {
    *    }
    * }
    * </code>
    * You can create your own classes that extend <code>TestSetup</code> so that you can reuse common
    * test suite <code>setUp()</code> and <code>tearDown()</code> functionality across
    * test suites.
    *
    * @see flexunit.framework.Test
    * @see flexunit.flexui.TestRunner
    * @see flexunit.extensions.TestSetup
    */
   "public class TestSuite implements flexunit.framework.Test",1,function($$private){var is=joo.is;return[
   

      /**
       * The TestSuite constructor, provided with the test to be run.
       * @param param The test class to be run. Can be a <code>TestCase</code>, another <code>TestSuite</code>
       * or any class that implements the <code>Test</code> interface.
       */
       "public function TestSuite",function TestSuite$( param/* : Object = null*/ )
       {if(arguments.length<1){param = null;}/*
           super()*/;
           this.testArrayList =/* flexunit.utils.Collection*/( new flexunit.utils.ArrayList());

           if( param == null )
               return;

           if (is(param,  Class))
           {
              var c/* : Class*/ =/* Class*/(param);
              var newClass/* : Test*/ = new c();
              this.addTestMethods$1( c, newClass );

              if ( this.testArrayList.length() == 0 )
              {
                  var warningTestCase/* : WarningTestCase*/ = new flexunit.framework.WarningTestCase( "No tests found in " + newClass.className );
                  this.addTestToList$1( warningTestCase );
              }
           }
           else if (is(param,  flexunit.framework.Test))
           {
               this.addTestToList$1(/*flexunit.framework.Test*/(param));
           }
           else
           {
               throw new Error("Can't handle constructor arg");
           }
       },

   //------------------------------------------------------------------------------
       "public function toString",function toString()/* : String*/
       {
           return "TestSuite";
       },

   //------------------------------------------------------------------------------

   /**
    * Runs the test, populating <code>result</code> with the test results.
    * @param result The <code>TestResult</code> instance to be populated with the test results.
    */
       "public function runWithResult",function runWithResult( result/* : TestResult*/ )/* : void*/
       {
           this.runIter$1 = this.testArrayList.iterator();
           this.listener$1 = new flexunit.framework.TestSuiteTestListener(this, result);
           this.runNext(result);
       },

       "public function runNext",function runNext( result/* : TestResult*/)/* : void*/
       {
           if ( this.runIter$1.hasNext() )
           {
               if ( result.shouldStop() )
               {
                   this.listener$1.pop();
                   return;
               }
               //note that the TestSuiteListener will make sure that runNext is called only occasionally so that
               //recursion doesn't spiral out of control
               var test/* : Test*/ =/* flexunit.framework.Test*/( this.runIter$1.next() );
               this.runTest$1( test, result );
           }
           else
           {
               this.listener$1.pop();
           }
       },

   //------------------------------------------------------------------------------

       "private function runTest",function runTest( test/* : Test*/, result/* : TestResult*/ )/* : void*/
       {
           test.runWithResult( result );
       },

   //------------------------------------------------------------------------------

   /**
    * Adds a test to this test suite.
    * @param test The <code>Test</code> instance to be added.
    */
       "public function addTest",function addTest( test/* : Test*/ )/* : void*/
       {
           if (!(is( test,  flexunit.framework.Test) ))
               this.addTest(/* flexunit.framework.Test*/( new flexunit.framework.WarningTestCase( "Object instance passed to addTest does not implement Test interface" )));
           else
               this.addTestToList$1( test );
       },

   //------------------------------------------------------------------------------

   /**
    * Wraps a test inside a <code>TestSuite</code> and adds it to this test suite.
    * @param testClass The <code>Class</code> that extends TestCase which will be added as a test suite.
    */
       "public function addTestSuite",function addTestSuite( testClass/* : Class*/ )/* : void*/
       {
          //addClassTestsToList( testClass );
           this.addTestToList$1( new flexunit.framework.TestSuite( testClass ));
       },

   //------------------------------------------------------------------------------

       "private function addTestMethods",function addTestMethods( theClass/* : Class*/, newClass/* : Test*/ )/* : void*/
       {
           var methodNames/* : Array*/ = newClass.getTestMethodNames();
           for ( var i/* : uint*/ =0; i<methodNames.length; i++ )
           {
               var method/* : String*/ = String( methodNames[i] );
               this.addTestMethod$1( theClass, method );
           }
       },

   //------------------------------------------------------------------------------

       "private function addTestMethod",function addTestMethod( theClass/* : Class*/, methodName/* : String*/ )/* : void*/
       {
           this.addTestToList$1( this.createTestInstance$1( theClass, methodName ));
       },

   //------------------------------------------------------------------------------

       "private function createTestInstance",function createTestInstance( theClass/* : Class*/, methodName/* : String*/ )/* : Test*/
       {
          var test/* : Test*/ = new theClass();
          if(is( test,  flexunit.framework.TestCase) )/* flexunit.framework.TestCase*/(test).methodName = methodName;

           return test;
       },

   //------------------------------------------------------------------------------

   /**
    * Returns the names of the test methods for this test.
    * @return  Array of method names for this test
   */
       "public function getTestMethodNames",function getTestMethodNames()/* : Array*/
       {
           return(null);
       },

   //------------------------------------------------------------------------------

   /**
    * Returns all the tests in this test suite as an <code>Array</code>
    * @return An <code>Array</code> containing the tests in this test suite.
    */
       "public function getTests",function getTests()/* : Array*/
       {
           return this.testArrayList.toArray();
       },

   //------------------------------------------------------------------------------

   /**
    * Iterates all tests in this suite to calculate the total number of tests in this suite.
    * @return A Number containing the count of all tests in this suite.
    */
       "public function countTestCases",function countTestCases()/* : Number*/
       {
           var count/* : Number*/ = 0;

           var iter/* : Iterator*/ = this.testArrayList.iterator();
           while ( iter.hasNext() )
           {
               var test/* : Test*/ =/* flexunit.framework.Test*/( iter.next() );
               count = count + test.countTestCases();
           }

           return count;
       },
         
   //------------------------------------------------------------------------------

   /**
    * The number of tests added to this suite.
    * @return A Number containing the number of tests added to this suite.
    */
       "public function testCount",function testCount()/* : Number*/
       {
           return this.testArrayList.length();
       },

   //------------------------------------------------------------------------------

   /**
    * Returns the fully qualified class name.
    * @return The fully qualified class name.
    */
       "public function get className",function className$get()/* : String*/
       {
           return(flash.utils.describeType(this).attribute("name").toString());
       },


   //------------------------------------------------------------------------------

       "private function addTestToList",function addTestToList( test/* : Test*/ )/* : void*/
       {
           this.testArrayList.addItem( test );
       },

   //------------------------------------------------------------------------------

       "public var",{ testArrayList/* : Collection*/:null},
       "public var",{ name/* : String*/:null},
       "private var",{ runIter/* : Iterator*/:null},
       "private var",{ listener/* : TestSuiteTestListener*/:null},

   ];},[],["flexunit.framework.Test","flexunit.utils.Collection","flexunit.utils.ArrayList","Class","flexunit.framework.WarningTestCase","Error","flexunit.framework.TestSuiteTestListener","String","flexunit.framework.TestCase"], "0.8.0", "0.8.3"
);

==> joounit-0.9.1.jar: joo/classes/flexunit/framework/TestSuite.js <==
joo.classLoader.prepare(/*
   Copyright (c) 2008. Adobe Systems Incorporated.
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
     * Neither the name of Adobe Systems Incorporated nor the names of its
       contributors may be used to endorse or promote products derived from this
       software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

"package flexunit.framework",/*
{
   
   import flash.utils.*;
   import flash.utils.describeType;
   
   import flexunit.utils.*;*/
   
   /**
    * A <code>TestSuite</code> is a collection of tests.
    * @description
    * It runs a collection of test cases. Here is an example:
    * import samples.test.com.iterationtwo.*;
    * import flexunit.framework.*;
    * import flexunit.extensions.*;
    *
    * <code>
    * import samples.test.com.iterationtwo.*;
    * import flexunit.framework.*;
    * import flexunit.extensions.*;
    *
    * class samples.test.com.iterationtwo.AllTests
    * {
    *    public static function suite() : Test
    *    {
    *       var testSuite : TestSuite = new TestSuite();
    *
    *       testSuite.addTest( new TestSuite( TestMoney ) );
    *       testSuite.addTest( new TestSuite( TestMoneyWithSetUpTearDown ) );
    *       testSuite.addTest( TestSuiteWithSetUpTearDown.suite() );
    *
    *       return testSuite;
    *    }
    * }
    * </code>
    * A <code>TestRunner</code> can be used to run the tests in a <code>TestSuite</code><br><br>
    * The <code>TestSetup</code>class lets you add <code>setUp()</code> and <code>tearDown()</code>
    * methods to initialize and clean-up your test suites, as shown in this example:
    * <code>
    * import samples.test.com.iterationtwo.*;
    * import flexunit.framework.*;
    * import flexunit.extensions.*;
    *
    * class samples.test.com.iterationtwo.TestSuiteWithSetUpTearDown
    * {
    *    public static function suite() : Test
    *    {
    *       var testSuite : TestSuite = new TestSuite();
    *
    *       testSuite.addTest( new TestSuite( TestMoneyWithFailingTests ) );
    *
    *       var testSetUp = new TestSetup( testSuite );
    *
    *       testSetUp.setUp = setUp
    *       testSetUp.tearDown = tearDown;
    *
    *       return testSetUp;
    *    }
    *
    *    public static function setUp()
    *    {
    *    }
    *
    *    public static function tearDown()
    *    {
    *    }
    * }
    * </code>
    * You can create your own classes that extend <code>TestSetup</code> so that you can reuse common
    * test suite <code>setUp()</code> and <code>tearDown()</code> functionality across
    * test suites.
    *
    * @see flexunit.framework.Test
    * @see flexunit.flexui.TestRunner
    * @see flexunit.extensions.TestSetup
    */
   "public class TestSuite implements flexunit.framework.Test",1,function($$private){var is=joo.is;return[
   

      /**
       * The TestSuite constructor, provided with the test to be run.
       * @param param The test class to be run. Can be a <code>TestCase</code>, another <code>TestSuite</code>
       * or any class that implements the <code>Test</code> interface.
       */
       "public function TestSuite",function TestSuite$( param/* : Object = null*/ )
       {if(arguments.length<1){param = null;}/*
           super()*/;
           this.testArrayList =/* flexunit.utils.Collection*/( new flexunit.utils.ArrayList());

           if( param == null )
               return;

           if (is(param,  Class))
           {
              var c/* : Class*/ =/* Class*/(param);
              var newClass/* : Test*/ = new c();
              this.addTestMethods$1( c, newClass );

              if ( this.testArrayList.length() == 0 )
              {
                  var warningTestCase/* : WarningTestCase*/ = new flexunit.framework.WarningTestCase( "No tests found in " + newClass.className );
                  this.addTestToList$1( warningTestCase );
              }
           }
           else if (is(param,  flexunit.framework.Test))
           {
               this.addTestToList$1(/*flexunit.framework.Test*/(param));
           }
           else
           {
               throw new Error("Can't handle constructor arg");
           }
       },

   //------------------------------------------------------------------------------
       "public function toString",function toString()/* : String*/
       {
           return "TestSuite";
       },

   //------------------------------------------------------------------------------

   /**
    * Runs the test, populating <code>result</code> with the test results.
    * @param result The <code>TestResult</code> instance to be populated with the test results.
    */
       "public function runWithResult",function runWithResult( result/* : TestResult*/ )/* : void*/
       {
           this.runIter$1 = this.testArrayList.iterator();
           this.listener$1 = new flexunit.framework.TestSuiteTestListener(this, result);
           this.runNext(result);
       },

       "public function runNext",function runNext( result/* : TestResult*/)/* : void*/
       {
           if ( this.runIter$1.hasNext() )
           {
               if ( result.shouldStop() )
               {
                   this.listener$1.pop();
                   return;
               }
               //note that the TestSuiteListener will make sure that runNext is called only occasionally so that
               //recursion doesn't spiral out of control
               var test/* : Test*/ =/* flexunit.framework.Test*/( this.runIter$1.next() );
               this.runTest$1( test, result );
           }
           else
           {
               this.listener$1.pop();
           }
       },

   //------------------------------------------------------------------------------

       "private function runTest",function runTest( test/* : Test*/, result/* : TestResult*/ )/* : void*/
       {
           test.runWithResult( result );
       },

   //------------------------------------------------------------------------------

   /**
    * Adds a test to this test suite.
    * @param test The <code>Test</code> instance to be added.
    */
       "public function addTest",function addTest( test/* : Test*/ )/* : void*/
       {
           if (!(is( test,  flexunit.framework.Test) ))
               this.addTest(/* flexunit.framework.Test*/( new flexunit.framework.WarningTestCase( "Object instance passed to addTest does not implement Test interface" )));
           else
               this.addTestToList$1( test );
       },

   //------------------------------------------------------------------------------

   /**
    * Wraps a test inside a <code>TestSuite</code> and adds it to this test suite.
    * @param testClass The <code>Class</code> that extends TestCase which will be added as a test suite.
    */
       "public function addTestSuite",function addTestSuite( testClass/* : Class*/ )/* : void*/
       {
          //addClassTestsToList( testClass );
           this.addTestToList$1( new flexunit.framework.TestSuite( testClass ));
       },

   //------------------------------------------------------------------------------

       "private function addTestMethods",function addTestMethods( theClass/* : Class*/, newClass/* : Test*/ )/* : void*/
       {
           var methodNames/* : Array*/ = newClass.getTestMethodNames();
           for ( var i/* : uint*/ =0; i<methodNames.length; i++ )
           {
               var method/* : String*/ = String( methodNames[i] );
               this.addTestMethod$1( theClass, method );
           }
       },

   //------------------------------------------------------------------------------

       "private function addTestMethod",function addTestMethod( theClass/* : Class*/, methodName/* : String*/ )/* : void*/
       {
           this.addTestToList$1( this.createTestInstance$1( theClass, methodName ));
       },

   //------------------------------------------------------------------------------

       "private function createTestInstance",function createTestInstance( theClass/* : Class*/, methodName/* : String*/ )/* : Test*/
       {
          var test/* : Test*/ = new theClass();
          if(is( test,  flexunit.framework.TestCase) )/* flexunit.framework.TestCase*/(test).methodName = methodName;

           return test;
       },

   //------------------------------------------------------------------------------

   /**
    * Returns the names of the test methods for this test.
    * @return  Array of method names for this test
   */
       "public function getTestMethodNames",function getTestMethodNames()/* : Array*/
       {
           return(null);
       },

   //------------------------------------------------------------------------------

   /**
    * Returns all the tests in this test suite as an <code>Array</code>
    * @return An <code>Array</code> containing the tests in this test suite.
    */
       "public function getTests",function getTests()/* : Array*/
       {
           return this.testArrayList.toArray();
       },

   //------------------------------------------------------------------------------

   /**
    * Iterates all tests in this suite to calculate the total number of tests in this suite.
    * @return A Number containing the count of all tests in this suite.
    */
       "public function countTestCases",function countTestCases()/* : Number*/
       {
           var count/* : Number*/ = 0;

           var iter/* : Iterator*/ = this.testArrayList.iterator();
           while ( iter.hasNext() )
           {
               var test/* : Test*/ =/* flexunit.framework.Test*/( iter.next() );
               count = count + test.countTestCases();
           }

           return count;
       },
         
   //------------------------------------------------------------------------------

   /**
    * The number of tests added to this suite.
    * @return A Number containing the number of tests added to this suite.
    */
       "public function testCount",function testCount()/* : Number*/
       {
           return this.testArrayList.length();
       },

   //------------------------------------------------------------------------------

   /**
    * Returns the fully qualified class name.
    * @return The fully qualified class name.
    */
       "public function get className",function className$get()/* : String*/
       {
           return(flash.utils.describeType(this).attribute("name").toString());
       },


   //------------------------------------------------------------------------------

       "private function addTestToList",function addTestToList( test/* : Test*/ )/* : void*/
       {
           this.testArrayList.addItem( test );
       },

   //------------------------------------------------------------------------------

       "public var",{ testArrayList/* : Collection*/:null},
       "public var",{ name/* : String*/:null},
       "private var",{ runIter/* : Iterator*/:null},
       "private var",{ listener/* : TestSuiteTestListener*/:null},

   ];},[],["flexunit.framework.Test","flexunit.utils.Collection","flexunit.utils.ArrayList","Class","flexunit.framework.WarningTestCase","Error","flexunit.framework.TestSuiteTestListener","String","flexunit.framework.TestCase"], "0.8.0", "0.9.1"
);
